ml_ephys

Electrophysiology tools
MountainLab processor library

Installation:
* clone this repository into .mountainlab/packages/
* Install the required python packages via:

cd ml_ephys
pip3 install --upgrade -r requirements.txt
